'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-21761734.js');
const clsx_m = require('./clsx.m-133931d3.js');

let LpTableCellHeader = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * Set the scope of the header cell.
     * I.e. whether the header cell is used within a row or a column (by default).
     */
    this.scope = 'col';
    /**
     * The type of the content.
     * Numeric content will be justified on the right.
     */
    this.type = 'text';
    /**
     * Whether the cell contains a checkbox for row selection or not.
     */
    this.hasCheckbox = false;
  }
  componentDidRender() {
    if (this.hasCheckbox) {
      const checkbox = document.querySelector('.mdc-checkbox');
      if (checkbox) {
        checkbox.classList.add('mdc-data-table__header-row-checkbox');
      }
    }
  }
  render() {
    return (index.h(index.Host, { class: "contents" }, index.h("th", { class: clsx_m.clsx('h-12 align-middle', // Patch styles due to `Host` element breaking inherited rules.
      {
        'mdc-data-table__cell': this.scope === 'row',
        'mdc-data-table__header-cell': this.scope === 'col',
        'mdc-data-table__header-cell--numeric': this.type === 'numeric',
        'mdc-data-table__header-cell--checkbox': this.hasCheckbox,
        'pl-3': this.hasCheckbox, // Fix left padding which is not correctly applied.
      }), role: this.scope === 'col' ? 'columnheader' : undefined, id: this.scope === 'row' ? this.cellId : undefined, scope: this.scope }, index.h("slot", null))));
  }
};

exports.lp_table_cell_header = LpTableCellHeader;
