'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-21761734.js');
const sdkCore = require('@listo-paye/sdk-core');
const intent_type = require('./intent.type-bfdcdaea.js');

let LpTransfer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.isOpen = false;
    // State-computed properties.
    this.loading = [];
    this.isLoading = true;
    this.hasErrors = false;
    this.errors = [];
    this.shouldDisablePrimaryAction = true;
    // @ts-ignore
    this.orderList = [];
    this.currentStep = 0;
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = sdkCore.store.getState();
      this.loading = sdkCore.selectLoading(this.state);
      this.errors = sdkCore.selectErrors(this.state);
      this.isLoading = !!this.loading.length;
      this.hasErrors = !!this.errors.length;
      this.shouldDisablePrimaryAction = this.isLoading || this.hasErrors;
      this.orderList = sdkCore.selectTransactionOrderList(this.state);
    };
    this.loadSDK = async () => {
      try {
        await sdkCore.init(this.config);
        await sdkCore.loadTransferData({
          date: this.date,
        });
      }
      catch (error) {
        console.error(error);
      }
    };
    this.previous = () => {
      this.currentStep--;
    };
    this.next = () => {
      this.currentStep++;
    };
    this.handleOpenView = async () => {
      this.isOpen = true;
      await this.loadSDK();
    };
    this.handleCancel = () => {
      if (this.isOpen) {
        this.isOpen = false;
      }
    };
    this.handleContinue = () => {
      if (!this.shouldDisablePrimaryAction) {
        this.next();
      }
    };
    this.handlePrevious = () => {
      if (!this.shouldDisablePrimaryAction) {
        this.previous();
      }
    };
    this.handleInitiatePayement = () => {
      if (!this.shouldDisablePrimaryAction) {
        this.transferPayload = sdkCore.selectTransferPayload(this.state);
        // DEBUG
        console.debug('transferPayload', this.transferPayload);
        //
      }
    };
  }
  async componentWillLoad() {
    // Initial call.
    this.handleStoreChange();
    // Global state subscription.
    this.unsubscribe = sdkCore.store.subscribe(this.handleStoreChange);
  }
  render() {
    const isStepSelection = this.isOpen && this.currentStep === 0;
    const isStepSummary = this.isOpen && this.currentStep === 1;
    const isStepRedirect = this.isOpen && this.currentStep === 2;
    if (isStepSelection) {
      return (index.h(index.Host, null, index.h("div", { onClick: this.handleOpenView }, index.h("slot", { name: "trigger-control" })), index.h("lp-dialog", { isOpen: this.isOpen, "dialog-title": "Payer les salaires", surfaceStyle: { minWidth: '800px', minHeight: '600px' } }, index.h("lp-view-selection", { slot: "content" }), index.h("lp-dialog-button", { slot: "action", onClicked: this.handleCancel }, "Annuler"), index.h("lp-dialog-button", { slot: "action", disabled: this.shouldDisablePrimaryAction, intent: intent_type.Intent.PRIMARY, onClicked: this.handleContinue }, this.hasErrors ? 'OK' : 'Continuer'))));
    }
    if (isStepSummary) {
      return (index.h(index.Host, null, index.h("div", { onClick: this.handleOpenView }, index.h("slot", { name: "trigger-control" })), index.h("lp-dialog", { isOpen: this.isOpen, "dialog-title": "Payer les salaires", surfaceStyle: { minWidth: '800px', minHeight: '600px' } }, index.h("lp-view-summary", { slot: "content" }), index.h("lp-dialog-button", { slot: "action", onClicked: this.handlePrevious }, this.hasErrors ? 'Annuler' : 'Précédent'), index.h("lp-dialog-button", { slot: "action", disabled: this.shouldDisablePrimaryAction, intent: intent_type.Intent.PRIMARY, onClicked: this.handleContinue }, this.hasErrors ? 'OK' : 'Initier le paiement'))));
    }
    if (isStepRedirect) {
      return (index.h(index.Host, null, index.h("div", { onClick: this.handleOpenView }, index.h("slot", { name: "trigger-control" })), index.h("lp-dialog", { isOpen: this.isOpen, "dialog-title": "Payer les salaires", surfaceStyle: { minWidth: '800px', minHeight: '600px' } }, index.h("lp-view-redirection", { slot: "content" }), index.h("lp-dialog-button", { slot: "action", onClicked: this.handlePrevious }, this.hasErrors ? 'Annuler' : 'Précédent'), index.h("lp-dialog-button", { slot: "action", disabled: this.shouldDisablePrimaryAction, intent: intent_type.Intent.PRIMARY, onClicked: this.handleContinue }, this.hasErrors ? 'OK' : 'Initier le paiement'))));
    }
    return (index.h(index.Host, null, index.h("div", { onClick: this.handleOpenView }, index.h("slot", { name: "trigger-control" }))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
};

exports.lp_transfer = LpTransfer;
