'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-21761734.js');
const sdkCore = require('@listo-paye/sdk-core');
const intent_type = require('./intent.type-bfdcdaea.js');

let LpViewRedirection = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    // State-computed properties.
    this.errors = [];
    this.isLoading = true;
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = sdkCore.store.getState();
      this.errors = sdkCore.selectErrors(this.state);
      const loading = sdkCore.selectLoading(this.state);
      this.isLoading = !!loading.length;
    };
    this.setupStore = () => {
      // Initial global State update.
      this.handleStoreChange();
      // Global state subscription.
      this.unsubscribe = sdkCore.store.subscribe(this.handleStoreChange);
    };
    this.handleInitiatePayement = async () => {
      this.redirectionUrl = await sdkCore.initiateTransfer();
    };
  }
  async componentWillLoad() {
    this.setupStore();
    await this.handleInitiatePayement();
  }
  render() {
    const hasErrors = !!this.errors.length;
    if (this.isLoading) {
      return index.h("p", null, "Loading...");
    }
    if (hasErrors) {
      return (index.h(index.Host, { class: "space-y-2" }, this.errors.map((error, index$1) => (index.h("lp-callout", { key: index$1, intent: intent_type.Intent.DANGER }, index.h("p", { slot: "message" }, error.message))))));
    }
    return (index.h(index.Host, { class: "flex items-center justify-center h-full" }, index.h("lp-anchor-button", { href: this.redirectionUrl,
      // target="_blank" // Open new tab or window.
      rel: "noreferrer" }, "Se connecter \u00E0 votre banque", index.h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-3 w-3 ml-0.5 mb-px", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor", "stroke-width": "2" }, index.h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", d: "M10 6H6a2 2 0 00-2 2v10a2 2 0 002 2h10a2 2 0 002-2v-4M14 4h6m0 0v6m0-6L10 14" })))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
};

exports.lp_view_redirection = LpViewRedirection;
