'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-21761734.js');
const sdkCore = require('@listo-paye/sdk-core');
const intent_type = require('./intent.type-bfdcdaea.js');

let LpViewSelection = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    // State-computed properties.
    this.errors = [];
    this.isLoading = true;
    this.orderList = [];
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = sdkCore.store.getState();
      this.errors = sdkCore.selectErrors(this.state);
      const loading = sdkCore.selectLoading(this.state);
      this.isLoading = !!loading.length;
      this.orderList = sdkCore.selectTransactionOrderList(this.state);
    };
    this.setupStore = () => {
      // Initial global State update.
      this.handleStoreChange();
      // Global state subscription.
      this.unsubscribe = sdkCore.store.subscribe(this.handleStoreChange);
    };
    this.handleSelectionChanged = (event) => {
      const selection = event.detail;
      const newOrderList = this.orderList.filter((order) => selection.includes(order.iban));
      sdkCore.setOrders(newOrderList);
    };
  }
  componentWillLoad() {
    this.setupStore();
  }
  render() {
    const hasErrors = !!this.errors.length;
    if (this.isLoading) {
      return index.h("p", null, "Nous pr\u00E9parons les donn\u00E9es de virements...");
    }
    if (hasErrors) {
      return (index.h(index.Host, { class: "space-y-2" }, this.errors.map((error, index$1) => (index.h("lp-callout", { key: index$1, intent: intent_type.Intent.DANGER }, index.h("p", { slot: "message" }, error.message))))));
    }
    return (index.h(index.Host, { class: "pt-4" }, index.h("p", null, "S\u00E9lectionner les salari\u00E9s auxquels vous souhaiter verser le salaire."), index.h("lp-table", { "aria-label": "Liste des sommes \u00E0 verser aux employ\u00E9s", class: "block mt-4", onSelectionChanged: this.handleSelectionChanged }, index.h("lp-table-row-header", { slot: "head" }, index.h("lp-table-cell-header", { "has-checkbox": "true" }, index.h("lp-checkbox", { "aria-label": "S\u00E9lectionner tous les rangs" })), index.h("lp-table-cell-header", null, "Employ\u00E9"), index.h("lp-table-cell-header", { type: "numeric" }, "Total"), index.h("lp-table-cell-header", null, "IBAN"), index.h("lp-table-cell-header", null, "RIB")), this.orderList.map((order) => (index.h("lp-table-row", { key: order.iban, "data-row-id": order.iban, slot: "body", selected: order.isEnabled }, index.h("lp-table-cell", null, index.h("lp-checkbox", { value: order.iban, checked: order.isEnabled, class: "mdc-data-table__row-checkbox", "aria-labelledby": order.iban })), index.h("lp-table-cell-header", { "cell-idc": order.iban, scope: "row" }, index.h("lp-employee", null, index.h("span", { slot: "firstName" }, order.prenom), index.h("span", { slot: "lastName", class: "font-bold" }, order.nom))), index.h("lp-table-cell", { type: "numeric" }, order.netAPayer, " \u20AC"), index.h("lp-table-cell", null, index.h("lp-iban", { iban: order.iban })), index.h("lp-table-cell", null, index.h("span", { class: "inline-block font-mono mdc-typography mdc-typography--body2" }, order.bic))))))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
};

exports.lp_view_selection = LpViewSelection;
