'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-21761734.js');
const sdkCore = require('@listo-paye/sdk-core');
const intent_type = require('./intent.type-bfdcdaea.js');

const sumOrderAmount = (total, amount) => total + amount;
let LpViewSummary = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    // State-computed properties.
    this.errors = [];
    this.isLoading = true;
    this.orderList = [];
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = sdkCore.store.getState();
      this.errors = sdkCore.selectErrors(this.state);
      const loading = sdkCore.selectLoading(this.state);
      this.isLoading = !!loading.length;
      this.orderList = sdkCore.selectTransactionOrderList(this.state);
    };
    this.setupStore = () => {
      // Initial global State update.
      this.handleStoreChange();
      // Global state subscription.
      this.unsubscribe = sdkCore.store.subscribe(this.handleStoreChange);
    };
  }
  componentWillLoad() {
    this.setupStore();
  }
  render() {
    const hasErrors = !!this.errors.length;
    if (this.isLoading) {
      return index.h("p", null, "Loading...");
    }
    if (hasErrors) {
      return (index.h(index.Host, { class: "space-y-2" }, this.errors.map((error, index$1) => (index.h("lp-callout", { key: index$1, intent: intent_type.Intent.DANGER }, index.h("p", { slot: "message" }, error.message))))));
    }
    const currentDate = new Date();
    const formattedCurrentDate = new Intl.DateTimeFormat('fr-FR').format(currentDate);
    const totalAmount = this.orderList
      .map((order) => order.netAPayer)
      .reduce(sumOrderAmount, 0);
    return (index.h(index.Host, { class: "flex flex-col space-y-4 pt-4" }, index.h("lp-callout", { intent: intent_type.Intent.PRIMARY }, index.h("span", { slot: "title" }, "Confirmer la demande de virement ?"), index.h("div", { slot: "message", class: "text-on-secondary/100" }, index.h("p", null, "Confirmez-vous la demande de virement dun total de", index.h("strong", { class: "ml-1 text-primary" }, totalAmount, " \u20AC"), " ?"), index.h("p", null, "Vous serez ensuite redirig\u00E9 vers le site de votre banque."))), index.h("lp-accordion", { label: "D\u00E9tails" }, index.h("p", null, index.h("ul", { class: "flex space-x-4" }, index.h("li", { class: "flex items-center space-x-2" }, index.h("span", { class: "mt-[2px] mdc-typography mdc-typography--overline leading-none" }, "P\u00E9riode de paiement"), index.h("span", { class: "mdc-typography mdc-typography--body2 text-primary" }, "2020-07-01")), index.h("li", { class: "flex items-center space-x-2" }, index.h("span", { class: "mt-[2px] mdc-typography mdc-typography--overline leading-none" }, "Date execution"), index.h("span", { class: "mdc-typography mdc-typography--body2 text-primary" }, formattedCurrentDate)))), index.h("lp-table", { "aria-label": "Liste des sommes \u00E0 verser aux employ\u00E9s", class: "block mt-4" }, index.h("lp-table-row-header", { slot: "head" }, index.h("lp-table-cell-header", null, "Employ\u00E9"), index.h("lp-table-cell-header", { type: "numeric" }, "Total"), index.h("lp-table-cell-header", null, "IBAN"), index.h("lp-table-cell-header", null, "RIB")), this.orderList.map((order) => (index.h("lp-table-row", { key: order.iban, "data-row-id": order.iban, slot: "body" }, index.h("lp-table-cell-header", { "cell-idc": order.iban, scope: "row" }, index.h("lp-employee", null, index.h("span", { slot: "firstName" }, order.prenom), index.h("span", { slot: "lastName", class: "font-bold" }, order.nom))), index.h("lp-table-cell", { type: "numeric" }, order.netAPayer, " \u20AC"), index.h("lp-table-cell", null, index.h("lp-iban", { iban: order.iban })), index.h("lp-table-cell", null, index.h("span", { class: "inline-block font-mono mdc-typography mdc-typography--body2" }, order.bic)))))))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
};

exports.lp_view_summary = LpViewSummary;
