import { Component, Event, h, Prop } from '@stencil/core';
import clsx from 'clsx';
import { Variant } from '../../types/variant.type';
export class LpAnchorButton {
  constructor() {
    /**
     * Button variant.
     */
    this.variant = Variant.CONTAINED;
    /**
     * Disable button.
     */
    this.disabled = false;
    this.handleClick = (event) => {
      this.clicked.emit(event);
    };
  }
  render() {
    if (this.disabled) {
      return (h("lp-button", { disabled: true, variant: this.variant },
        h("slot", null)));
    }
    return (h("a", { class: clsx('mdc-button', {
        'mdc-button--outlined': this.variant === Variant.OUTLINED,
        'mdc-button--raised': this.variant === Variant.CONTAINED,
      }), "aria-disabled": this.disabled, href: this.href, rel: this.rel, target: this.target, onClick: this.handleClick },
      h("div", { class: "mdc-button__ripple" }),
      h("span", { class: "mdc-button__label flex items-center" },
        h("slot", null))));
  }
  static get is() { return "lp-anchor-button"; }
  static get properties() { return {
    "href": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "HTMLAnchorElement['href']",
        "resolved": "string",
        "references": {
          "HTMLAnchorElement": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "href",
      "reflect": false
    },
    "target": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "HTMLAnchorElement['target']",
        "resolved": "string",
        "references": {
          "HTMLAnchorElement": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "target",
      "reflect": false
    },
    "rel": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "HTMLAnchorElement['rel']",
        "resolved": "string",
        "references": {
          "HTMLAnchorElement": {
            "location": "global"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "rel",
      "reflect": false
    },
    "variant": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Exclude<Variant, 'filled'>",
        "resolved": "\"contained\" | \"outlined\" | \"text\"",
        "references": {
          "Exclude": {
            "location": "global"
          },
          "Variant": {
            "location": "import",
            "path": "../../types/variant.type"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Button variant."
      },
      "attribute": "variant",
      "reflect": false,
      "defaultValue": "Variant.CONTAINED"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Disable button."
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get events() { return [{
      "method": "clicked",
      "name": "clicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "MouseEvent",
        "resolved": "MouseEvent",
        "references": {
          "MouseEvent": {
            "location": "global"
          }
        }
      }
    }]; }
}
