import { html } from 'lit-html';
import { Variant } from '../../types/variant.type';
import readme from './readme.md';
const argTypes = {
  variant: {
    options: Object.values(Variant),
    control: { type: 'select' },
  },
  href: {
    type: { name: 'string', required: true },
    description: 'Text of the button which is always shown.',
    table: {
      type: { summary: 'string' },
    },
  },
  disabled: {
    type: { name: 'boolean', required: true },
    description: 'Disable anchor button.',
    table: {
      type: { summary: 'boolean' },
    },
  },
};
export default {
  title: 'Lp Anchor Button',
  parameters: {
    notes: readme,
    actions: {
      handles: ['clicked'],
    },
  },
  argTypes,
};
const Template = ({ href, disabled, variant, slot, onClicked }) => html `<lp-anchor-button
    ?disabled=${disabled}
    href=${href}
    variant=${variant}
    @clicked=${onClicked}
    >${slot}</lp-anchor-button
  >`;
export const Primary = Template.bind({});
Primary.args = {
  disabled: false,
  href: '#',
  variant: Variant.CONTAINED,
  slot: 'Se connecter à votre banque',
  onClicked: (event) => console.log(event),
};
export const Outlined = Template.bind({});
Outlined.args = {
  disabled: false,
  href: '#',
  variant: Variant.OUTLINED,
  slot: 'Se connecter à votre banque',
  onClicked: (event) => console.log(event),
};
export const Disabled = Template.bind({});
Disabled.args = {
  disabled: true,
  href: '#',
  slot: 'Se connecter à votre banque',
  onClicked: (event) => console.log(event),
};
const WithIconTemplate = ({ href, disabled, variant, slot, onClicked }) => html `<lp-anchor-button
    ?disabled=${disabled}
    href=${href}
    variant=${variant}
    @clicked=${onClicked}
    >${slot}
    <svg
      xmlns="http://www.w3.org/2000/svg"
      class="h-3 w-3 ml-0.5 mb-px"
      fill="none"
      viewBox="0 0 24 24"
      stroke="currentColor"
      stroke-width="2"
    >
      <path
        stroke-linecap="round"
        stroke-linejoin="round"
        d="M10 6H6a2 2 0 00-2 2v10a2 2 0 002 2h10a2 2 0 002-2v-4M14 4h6m0 0v6m0-6L10 14"
      />
    </svg>
  </lp-anchor-button>`;
export const WithIcon = WithIconTemplate.bind({});
WithIcon.args = {
  disabled: false,
  href: '#',
  variant: Variant.CONTAINED,
  slot: 'Se connecter à votre banque',
  onClicked: (event) => console.log(event),
};
