import { html } from 'lit-html';
import { Intent } from '../../types/intent.type';
import readme from './readme.md';
const argTypes = {
  intent: {
    type: { name: 'Intent', required: false },
    defaultValue: false,
    description: 'Visual intent color to apply to background, title, and icon.',
    table: {
      type: { summary: 'Intent' },
      defaultValue: { summary: false },
    },
    options: Object.values(Intent),
  },
};
export default {
  title: 'Lp Callout',
  parameters: {
    notes: readme,
  },
  argTypes,
};
const Template = ({ intent, title, message }) => {
  if (title && message) {
    return html `<lp-callout intent=${intent}>
      <span slot="title">${title}</span>
      <span slot="message">${message}</span>
    </lp-callout>`;
  }
  if (title) {
    return html `<lp-callout intent=${intent}>
      <span slot="title">${title}</span>
    </lp-callout>`;
  }
  return html `<lp-callout intent=${intent}>
    <span slot="message">${message}</span>
  </lp-callout>`;
};
export const Idle = Template.bind({});
Idle.args = {
  message: 'Vous allez être redirigé vers votre banque.',
};
export const WithTitle = Template.bind({});
WithTitle.args = {
  title: 'Information',
  message: 'Vous allez être redirigé vers votre banque.',
};
export const WithDangerIntent = Template.bind({});
WithDangerIntent.args = {
  intent: Intent.DANGER,
  title: 'Information',
  message: "Malheureusement votre banque n'est pas encore supportée par notre système de virement des salaires.",
};
export const WithSuccessIntent = Template.bind({});
WithSuccessIntent.args = {
  intent: Intent.SUCCESS,
  title: 'Votre ordre de virement a bien été effectué !',
};
