import { MDCCheckbox } from '@material/checkbox';
import { Component, Element, h, Prop } from '@stencil/core';
/**
 *
 */
export class LpCheckbox {
  constructor() {
    /**
     * Whether checkbox is indeterminate or not.
     */
    this.indeterminate = false;
    /**
     * Whether checkbox is checked or not.
     */
    this.checked = false;
    /**
     * Whether checkbox is disabled or not.
     */
    this.disabled = false;
    this.syncInternalCheckboxState = () => {
      this.checkbox.value = this.value;
      this.checkbox.indeterminate = this.indeterminate;
      this.checkbox.checked = this.checked;
      this.checkbox.disabled = this.disabled;
    };
    this.initiateCheckbox = () => {
      this.checkbox = new MDCCheckbox(this.hostElement.querySelector('.mdc-checkbox'));
      if (!this.checkbox) {
        throw new Error('Unable to initiate MDCCheckbox component. Be sure it is mounted into the DOM.');
      }
      this.syncInternalCheckboxState();
    };
  }
  componentDidLoad() {
    this.initiateCheckbox();
  }
  componentWillUpdate() {
    this.syncInternalCheckboxState();
  }
  render() {
    return (h("div", { class: "mdc-checkbox" },
      h("input", { type: "checkbox", id: this.inputId, class: "mdc-checkbox__native-control", "aria-label": this.ariaLabel }),
      h("div", { class: "mdc-checkbox__background" },
        h("svg", { class: "mdc-checkbox__checkmark", viewBox: "0 0 24 24" },
          h("path", { class: "mdc-checkbox__checkmark-path", fill: "none", d: "M1.73,12.91 8.1,19.28 22.79,4.59" })),
        h("div", { class: "mdc-checkbox__mixedmark" })),
      h("div", { class: "mdc-checkbox__ripple" })));
  }
  static get is() { return "lp-checkbox"; }
  static get properties() { return {
    "inputId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The id of the checkbox used to identify its label within a field form."
      },
      "attribute": "input-id",
      "reflect": false
    },
    "ariaLabel": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Accessible label used when checkbox is not used within a field form."
      },
      "attribute": "aria-label",
      "reflect": false
    },
    "ariaLabelledby": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Set the id of the element acting as label of this checkbox."
      },
      "attribute": "aria-labelledby",
      "reflect": false
    },
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The current value of the checkbox."
      },
      "attribute": "value",
      "reflect": false
    },
    "indeterminate": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether checkbox is indeterminate or not."
      },
      "attribute": "indeterminate",
      "reflect": false,
      "defaultValue": "false"
    },
    "checked": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether checkbox is checked or not."
      },
      "attribute": "checked",
      "reflect": false,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether checkbox is disabled or not."
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get elementRef() { return "hostElement"; }
}
