import { Component, Event, h, Listen, Prop } from '@stencil/core';
import { Intent } from '../../types/intent.type';
import { Variant } from '../../types/variant.type';
/**
 * Main button used within Dialog.
 *
 * @slot content - Main content of the button typically text.
 *
 */
export class LpDialogButton {
  constructor() {
    this.intent = Intent.NONE;
    this.disabled = false;
  }
  handleClick(event) {
    event.stopPropagation();
    if (!this.disabled) {
      this.clicked.emit(event);
    }
  }
  render() {
    const variant = this.intent === Intent.PRIMARY ? Variant.CONTAINED : Variant.TEXT;
    const action = this.intent === Intent.PRIMARY ? 'primary' : 'secondary';
    return (h("lp-button", { class: "mdc-dialog__button", variant: variant, disabled: this.disabled, "data-mdc-dialog-action": action, "data-mdc-dialog-button-default": this.default },
      h("slot", null)));
  }
  static get is() { return "lp-dialog-button"; }
  static get properties() { return {
    "intent": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "LpDialogButtonIntent",
        "resolved": "\"none\" | \"primary\"",
        "references": {
          "LpDialogButtonIntent": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "intent",
      "reflect": false,
      "defaultValue": "Intent.NONE"
    },
    "default": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "default",
      "reflect": false
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
  static get events() { return [{
      "method": "clicked",
      "name": "clicked",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "CustomEvent<MouseEvent>",
        "resolved": "CustomEvent<MouseEvent>",
        "references": {
          "CustomEvent": {
            "location": "global"
          },
          "MouseEvent": {
            "location": "global"
          }
        }
      }
    }]; }
  static get listeners() { return [{
      "name": "click",
      "method": "handleClick",
      "target": undefined,
      "capture": true,
      "passive": false
    }]; }
}
