import { html } from 'lit-html';
import { Intent } from '../../types/intent.type';
import readme from './readme.md';
const argTypes = {
  intent: {
    type: { name: 'LpDialogButtonIntent', required: false },
    defaultValue: Intent.NONE,
    description: 'Whether the dialog is opened or not.',
    table: {
      type: { summary: 'LpDialogButtonIntent' },
      defaultValue: { summary: false },
    },
  },
  onSecondaryClicked: {
    name: 'secondaryClicked',
    type: { name: 'Event', required: false },
    description: 'Emitted event when user clicked on the secondary action button.',
    table: {
      type: { summary: 'Event' },
    },
  },
  onPrimaryClicked: {
    name: 'primaryClicked',
    type: { name: 'Event', required: false },
    description: 'Emitted event when user clicked on the primary action button.',
    table: {
      type: { summary: 'Event' },
    },
  },
};
export default {
  title: 'Lp Dialog Button',
  parameters: {
    notes: readme,
    actions: {
      handles: ['primaryClicked', 'secondaryClicked'],
    },
  },
  argTypes,
};
const Template = ({ intent, text, onSecondaryClicked, onPrimaryClicked }) => {
  return html `
    <lp-dialog-button
      intent=${intent}
      @secondaryClicked=${onSecondaryClicked}
      @primaryClicked=${onPrimaryClicked}
    >
      ${text}
    </lp-dialog-button>
  `;
};
export const Idle = Template.bind({});
Idle.args = {
  intent: undefined,
  text: 'Annuler',
  onSecondaryClicked: () => {
    console.log('Canceled');
  },
};
export const PrimaryAction = Template.bind({});
PrimaryAction.args = {
  intent: Intent.PRIMARY,
  text: 'Confirmer',
  onPrimaryClicked: () => {
    console.log('Confirmed');
  },
};
