import { MDCDialog } from '@material/dialog';
import { Component, h, Prop } from '@stencil/core';
/**
 * Modal view which should display some data related to transfer.
 *
 * @slot content - Main content of the dialog.
 */
export class LpDialog {
  constructor() {
    /**
     * Title of the dialog showed on the top.
     */
    this.dialogTitle = 'Payer les salaires';
  }
  componentDidRender() {
    this.dialog = new MDCDialog(document.querySelector('.mdc-dialog'));
    if (!this.dialog) {
      throw new Error('Unable to initiate MDCDialog component. Be sure it is mounted into the DOM.');
    }
    if (this.isOpen) {
      this.dialog.open();
    }
  }
  render() {
    return (h("div", { class: "mdc-dialog" },
      h("div", { class: "mdc-dialog__container" },
        h("div", { class: "mdc-dialog__surface", style: this.surfaceStyle, role: "alertdialog", "aria-modal": "true", "aria-labelledby": "lp-dialog-title", "aria-describedby": "lp-dialog-content", "data-mdc-dialog-initial-focus": "close" },
          h("div", { class: "mdc-dialog__header relative" },
            h("h2", { class: "mdc-dialog__title", id: "lp-dialog-title" }, this.dialogTitle),
            h("button", { class: "mdc-icon-button mdc-dialog__close absolute top-1 right-2", "data-mdc-dialog-action": "close" },
              h("svg", { xmlns: "http://www.w3.org/2000/svg", viewBox: "0 0 20 20", fill: "currentColor" },
                h("path", { "fill-rule": "evenodd", d: "M4.293 4.293a1 1 0 011.414 0L10 8.586l4.293-4.293a1 1 0 111.414 1.414L11.414 10l4.293 4.293a1 1 0 01-1.414 1.414L10 11.414l-4.293 4.293a1 1 0 01-1.414-1.414L8.586 10 4.293 5.707a1 1 0 010-1.414z", "clip-rule": "evenodd" })))),
          h("div", { class: "mdc-dialog__content", id: "lp-dialog-content" },
            h("slot", { name: "content" })),
          h("lp-dialog-actions", null,
            h("slot", { name: "action" })))),
      h("div", { class: "mdc-dialog__scrim" })));
  }
  static get is() { return "lp-dialog"; }
  static get properties() { return {
    "isOpen": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Whether the dialog is opened or not."
      },
      "attribute": "open",
      "reflect": false
    },
    "dialogTitle": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Title of the dialog showed on the top."
      },
      "attribute": "dialog-title",
      "reflect": false,
      "defaultValue": "'Payer les salaires'"
    },
    "surfaceStyle": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Style",
        "resolved": "{ [key: string]: string; }",
        "references": {
          "Style": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Style of the dialog surface."
      }
    }
  }; }
}
