import { html } from 'lit-html';
import { Intent } from '../../types/intent.type';
import readme from './readme.md';
const argTypes = {
  open: {
    type: { name: 'boolean', required: false },
    defaultValue: false,
    description: 'Whether the dialog is opened or not.',
    table: {
      type: { summary: 'boolean' },
      defaultValue: { summary: false },
    },
  },
  dialogTitle: {
    name: 'dialog-title',
    type: { name: 'string', required: true },
    defaultValue: 'Payer les salaires',
    description: 'Title of the dialog showed on the top.',
    table: {
      type: { summary: 'string' },
      defaultValue: { summary: 'Payer les salaires' },
    },
  },
  surfaceStyle: {
    name: 'surface-style',
    type: { name: 'Style', required: false },
    description: 'Style of the dialog surface.',
    table: {
      type: { summary: 'Style' },
    },
  },
  onSecondaryClicked: {
    name: 'secondaryClicked',
    type: { name: 'Event', required: false },
    description: 'Emitted event when user clicked on the secondary action button.',
    table: {
      type: { summary: 'Event' },
    },
  },
  onPrimaryClicked: {
    name: 'primaryClicked',
    type: { name: 'Event', required: false },
    description: 'Emitted event when user clicked on the primary action button.',
    table: {
      type: { summary: 'Event' },
    },
  },
};
export default {
  title: 'Lp Dialog',
  parameters: {
    notes: readme,
    actions: {
      handles: ['primaryClicked', 'secondaryClicked'],
    },
  },
  argTypes,
};
const Template = ({ open, dialogTitle, surfaceStyle, secondaryActionText, primaryActionText, onSecondaryClicked, onPrimaryClicked, }) => {
  return html `<lp-dialog
    ?open=${open}
    dialog-title=${dialogTitle}
    .surfaceStyle=${surfaceStyle}
    @secondaryClicked=${onSecondaryClicked}
    @primaryClicked=${onPrimaryClicked}
  >
    <div slot="content">
      <p>Content goes here.</p>
    </div>

    <lp-dialog-button slot="action">${secondaryActionText}</lp-dialog-button>
    <lp-dialog-button slot="action" intent=${Intent.PRIMARY}
      >${primaryActionText}</lp-dialog-button
    >
  </lp-dialog>`;
};
export const Idle = Template.bind({});
Idle.args = {
  open: true,
  dialogTitle: 'Payer les salaires',
  surfaceStyle: undefined,
  secondaryActionText: 'Annuler',
  primaryActionText: 'Confirmer',
  onSecondaryClicked: () => {
    console.log('Canceled');
  },
  onPrimaryClicked: () => {
    console.log('Confirmed');
  },
};
export const WithCustomSize = Template.bind({});
WithCustomSize.args = {
  open: true,
  dialogTitle: 'Payer les salaires',
  surfaceStyle: { minWidth: '800px', minHeight: '600px' },
  secondaryActionText: 'Annuler',
  primaryActionText: 'Confirmer',
  onSecondaryClicked: () => {
    console.log('Canceled');
  },
  onPrimaryClicked: () => {
    console.log('Confirmed');
  },
};
