import { Component, h, Prop } from '@stencil/core';
import clsx from 'clsx';
/**
 * Option which should be placed within a `lp-select`.
 *
 */
export class LpSelectOption {
  constructor() {
    /**
     * Whether option is selected or not.
     */
    this.selected = false;
  }
  // mdc-list-item--with-one-line
  render() {
    return (h("li", { class: clsx('mdc-list-item', {
        'mdc-list-item--selected': this.selected,
        'mdc-list-item--disabled': this.disabled,
      }), "aria-selected": this.selected, "aria-disabled": this.disabled, "data-value": this.value, role: "option" },
      h("span", { class: "mdc-list-item__ripple" }),
      h("span", { class: "mdc-list-item__text" },
        h("slot", null))));
  }
  static get is() { return "lp-select-option"; }
  static get properties() { return {
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Value used by `lp-select` to identify currently selected option."
      },
      "attribute": "value",
      "reflect": false
    },
    "selected": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether option is selected or not."
      },
      "attribute": "selected",
      "reflect": false,
      "defaultValue": "false"
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether option is selectable or not."
      },
      "attribute": "disabled",
      "reflect": false
    }
  }; }
}
