import { MDCSelect } from '@material/select';
import { Component, Event, h, Host, Prop } from '@stencil/core';
import clsx from 'clsx';
export class LpSelect {
  constructor() {
    /**
     * Whether select is disabled or not.
     */
    this.disabled = false;
    /**
     * Whether select is required or not.
     */
    this.required = false;
    /**
     * The index of the currently selected option.
     * Set to -1 if no option is currently selected.
     * Changing this property will update the select element.
     */
    this.selectedIndex = -1;
    /**
     * Whether the component is in a valid state.
     * Setting this updates styles on the component, but does not affect the native validity state.
     */
    this.valid = true;
  }
  componentDidRender() {
    this.select = new MDCSelect(document.querySelector('.mdc-select'));
    if (!this.select) {
      throw new Error('Unable to initiate MDCSelect component. Be sure it is mounted into the DOM.');
    }
    this.select.disabled = this.disabled;
    this.select.required = this.required;
    this.select.valid = this.valid;
    this.select.value = this.value;
    this.select.selectedIndex = this.selectedIndex;
    this.select.helperTextContent = this.helperText;
    this.select.listen('MDCSelect:change', () => {
      this.changed.emit({ value: this.value, index: this.selectedIndex });
    });
  }
  render() {
    const labelId = `${this.labelledby}-label`;
    const labelIdSelected = `${labelId}-selected`;
    const labelListBox = `${this.label} listbox`;
    const helperTextId = `${this.labelledby}-helper-text`;
    const style = { width: this.width || 'unset' };
    return (h(Host, null,
      h("div", { class: "mdc-select mdc-select--filled", style: style },
        h("div", { class: "mdc-select__anchor", role: "button", "aria-haspopup": "listbox", "aria-expanded": "false", "aria-labelledby": clsx(labelId, labelIdSelected), "aria-controls": helperTextId, "aria-describedby": helperTextId },
          h("span", { class: "mdc-select__ripple" }),
          h("span", { id: labelId, class: "mdc-floating-label" }, this.label),
          h("span", { class: "mdc-select__selected-text-container" },
            h("span", { id: labelIdSelected, class: "mdc-select__selected-text" })),
          h("span", { class: "mdc-select__dropdown-icon" },
            h("svg", { class: "mdc-select__dropdown-icon-graphic", viewBox: "7 10 10 5", focusable: "false" },
              h("polygon", { class: "mdc-select__dropdown-icon-inactive", stroke: "none", 
                // fillRule="evenodd"
                points: "7 10 12 15 17 10" }),
              h("polygon", { class: "mdc-select__dropdown-icon-active", stroke: "none", 
                // fillRule="evenodd"
                points: "7 15 12 10 17 15" }))),
          h("span", { class: "mdc-line-ripple" })),
        h("div", { class: "mdc-select__menu mdc-menu mdc-menu-surface mdc-menu-surface--fullwidth" },
          h("ul", { class: "mdc-list", role: "listbox", "aria-label": labelListBox },
            h("slot", null)))),
      h("p", { id: helperTextId, class: "mdc-select-helper-text" }, this.helperText)));
  }
  static get is() { return "lp-select"; }
  static get properties() { return {
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Text describing the field."
      },
      "attribute": "label",
      "reflect": false
    },
    "labelledby": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Unique id used to identify accessible label element of the field."
      },
      "attribute": "labelledby",
      "reflect": false
    },
    "width": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Set the width of the select & its menu."
      },
      "attribute": "width",
      "reflect": false
    },
    "disabled": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether select is disabled or not."
      },
      "attribute": "disabled",
      "reflect": false,
      "defaultValue": "false"
    },
    "required": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether select is required or not."
      },
      "attribute": "required",
      "reflect": false,
      "defaultValue": "false"
    },
    "value": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The `value` / `data-value` of the currently selected option."
      },
      "attribute": "value",
      "reflect": false
    },
    "selectedIndex": {
      "type": "number",
      "mutable": false,
      "complexType": {
        "original": "number",
        "resolved": "number",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The index of the currently selected option.\nSet to -1 if no option is currently selected.\nChanging this property will update the select element."
      },
      "attribute": "selected-index",
      "reflect": false,
      "defaultValue": "-1"
    },
    "helperText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Set helper text to give more details about the field or validation messages."
      },
      "attribute": "helper-text",
      "reflect": false
    },
    "valid": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether the component is in a valid state.\nSetting this updates styles on the component, but does not affect the native validity state."
      },
      "attribute": "valid",
      "reflect": false,
      "defaultValue": "true"
    }
  }; }
  static get events() { return [{
      "method": "changed",
      "name": "changed",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "LpSelectChangeEvent",
        "resolved": "LpSelectChangeEvent",
        "references": {
          "LpSelectChangeEvent": {
            "location": "local"
          }
        }
      }
    }]; }
}
