import { Component, h, Host, Prop } from '@stencil/core';
import clsx from 'clsx';
/**
 * Header of a group of table cells.
 *
 * @slot - Header cell content.
 *
 */
export class LpTableCellHeader {
  constructor() {
    /**
     * Set the scope of the header cell.
     * I.e. whether the header cell is used within a row or a column (by default).
     */
    this.scope = 'col';
    /**
     * The type of the content.
     * Numeric content will be justified on the right.
     */
    this.type = 'text';
    /**
     * Whether the cell contains a checkbox for row selection or not.
     */
    this.hasCheckbox = false;
  }
  componentDidRender() {
    if (this.hasCheckbox) {
      const checkbox = document.querySelector('.mdc-checkbox');
      if (checkbox) {
        checkbox.classList.add('mdc-data-table__header-row-checkbox');
      }
    }
  }
  render() {
    return (h(Host, { class: "contents" },
      h("th", { class: clsx('h-12 align-middle', // Patch styles due to `Host` element breaking inherited rules.
        {
          'mdc-data-table__cell': this.scope === 'row',
          'mdc-data-table__header-cell': this.scope === 'col',
          'mdc-data-table__header-cell--numeric': this.type === 'numeric',
          'mdc-data-table__header-cell--checkbox': this.hasCheckbox,
          'pl-3': this.hasCheckbox, // Fix left padding which is not correctly applied.
        }), role: this.scope === 'col' ? 'columnheader' : undefined, id: this.scope === 'row' ? this.cellId : undefined, scope: this.scope },
        h("slot", null))));
  }
  static get is() { return "lp-table-cell-header"; }
  static get properties() { return {
    "scope": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'col' | 'row'",
        "resolved": "\"col\" | \"row\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Set the scope of the header cell.\nI.e. whether the header cell is used within a row or a column (by default)."
      },
      "attribute": "scope",
      "reflect": false,
      "defaultValue": "'col'"
    },
    "cellId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "Id",
        "resolved": "string",
        "references": {
          "Id": {
            "location": "import",
            "path": "../../types/id.type"
          }
        }
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Unique identifier of the cell which should be used when the `scope` is row."
      },
      "attribute": "cell-id",
      "reflect": false
    },
    "type": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'text' | 'numeric'",
        "resolved": "\"numeric\" | \"text\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The type of the content.\nNumeric content will be justified on the right."
      },
      "attribute": "type",
      "reflect": false,
      "defaultValue": "'text'"
    },
    "hasCheckbox": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether the cell contains a checkbox for row selection or not."
      },
      "attribute": "has-checkbox",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
}
