import { html } from 'lit-html';
import readme from './readme.md';
const argTypes = {
  scope: {
    type: { name: 'col | row', required: false },
    defaultValue: 'col',
    description: 'Set the scope of the header cell.\n I.e. whether the header cell is used within a row or a column (by default).',
    table: {
      type: { summary: 'col | row' },
      defaultValue: { summary: 'col' },
    },
    options: ['col', 'row'],
    control: { type: 'select' },
  },
  cellId: {
    name: 'cell-id',
    type: { name: 'string', required: false },
    description: 'Unique identifier of the cell which should be used when the `scope` is row.',
    table: {
      type: { summary: 'string' },
    },
  },
  type: {
    type: { name: 'text | numeric', required: false },
    defaultValue: 'text',
    description: 'The type of the content.\n Numeric content will be justified on the right.',
    table: {
      type: { summary: 'text | numeric' },
      defaultValue: { summary: 'text' },
    },
    options: ['text', 'numeric'],
    control: {
      type: 'select',
    },
  },
};
export default {
  title: 'Lp Table Cell Header',
  parameters: {
    notes: readme,
  },
  argTypes,
};
const Template = ({ scope, cellId, type, slot }) => html `<lp-table-cell-header scope=${scope} cell-id=${cellId} type=${type}
    >${slot}</lp-table-cell-header
  >`;
export const Idle = Template.bind({});
Idle.args = {
  scope: 'col',
  type: 'text',
  slot: 'Employé',
};
export const RowHeader = Template.bind({});
RowHeader.args = {
  scope: 'row',
  type: 'text',
  cellId: 'u0',
  slot: 'Hubert Bonisseur De La Bath',
};
export const WithCheckbox = () => html `<lp-table-cell-header has-checkbox="true"
  ><lp-checkbox
/></lp-table-cell-header> `;
