import { Component, h, Host, Prop } from '@stencil/core';
import clsx from 'clsx';
/**
 * Table cell that contains data.
 *
 * @slot - Contains data.
 *
 */
export class LpTableCell {
  constructor() {
    /**
     * The type of the content.
     * Numeric content will be justified on the right.
     */
    this.type = 'text';
    /**
     * Whether the cell contains a checkbox for row selection or not.
     */
    this.hasCheckbox = false;
  }
  componentDidRender() {
    // Add an extra specific CSS class to the inner checkbox if it exists.
    if (this.hasCheckbox) {
      const checkbox = document.querySelector('.mdc-checkbox');
      if (checkbox) {
        checkbox.classList.add('mdc-data-table__row-checkbox');
      }
    }
  }
  render() {
    return (h(Host, { class: "contents" },
      h("td", { class: clsx('h-12 align-middle', // Patch styles due to `Host` element breaking inherited rules.
        'mdc-data-table__cell', {
          'mdc-data-table__cell--numeric': this.type === 'numeric',
          'mdc-data-table__cell--checkbox': this.hasCheckbox,
        }) },
        h("slot", null))));
  }
  static get is() { return "lp-table-cell"; }
  static get properties() { return {
    "type": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "'text' | 'numeric'",
        "resolved": "\"numeric\" | \"text\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "The type of the content.\nNumeric content will be justified on the right."
      },
      "attribute": "type",
      "reflect": false,
      "defaultValue": "'text'"
    },
    "hasCheckbox": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Whether the cell contains a checkbox for row selection or not."
      },
      "attribute": "has-checkbox",
      "reflect": false,
      "defaultValue": "false"
    }
  }; }
}
