import { html } from 'lit-html';
import readme from './readme.md';
const argTypes = {
  dataRowId: {
    name: 'data-row-id',
    type: { name: 'string', required: true },
    description: 'Unique row identifier.',
    table: {
      type: { summary: 'string' },
    },
  },
  isSelected: {
    name: 'selected',
    type: { name: 'boolean', required: false },
    description: 'Whether row is selected or not.',
    table: {
      type: { summary: 'boolean' },
    },
  },
};
export default {
  title: 'Lp Table Row',
  parameters: {
    notes: readme,
  },
  argTypes,
};
const Template = ({ selected }) => html `
  <lp-table>
    <lp-table-row>
      <lp-table-cell>
        <lp-checkbox
          value="some-selected-value"
          checked=${selected}
          class="mdc-data-table__row-checkbox"
          aria-labelledby="some-selected-value"
        />
      </lp-table-cell>

      <lp-table-cell-header cell-idc="{index}" scope="row">
        <lp-employee>
          <span slot="firstName">John</span>
          <span slot="lastName" class="font-bold">Appleseed</span>
        </lp-employee>
      </lp-table-cell-header>
    </lp-table-row>
  </lp-table>
`;
export const Idle = Template.bind({});
Idle.args = {
  selected: false,
};
export const Selected = Template.bind({});
Selected.args = {
  selected: true,
};
