import { MDCDataTable } from '@material/data-table';
import { Component, Event, h, Host, Prop } from '@stencil/core';
/**
 * Table component displays information in a two-dimensional table
 * comprised of rows and columns of cells containing data.
 *
 * @slot head - Table `thead` content.
 * @slot body - Table `tbody` content.
 *
 */
export class LpTable {
  constructor() {
    this.updateSelectedRowsIds = () => {
      var _a;
      this.selectedRowIds = (_a = this.table) === null || _a === void 0 ? void 0 : _a.getSelectedRowIds();
    };
    this.handleChangeSelection = () => {
      this.updateSelectedRowsIds();
      this.selectionChanged.emit(this.selectedRowIds);
    };
  }
  componentDidRender() {
    this.table = new MDCDataTable(document.querySelector('.mdc-data-table'));
    if (!this.table) {
      throw new Error('Unable to initiate MDCDataTable component. Be sure it is mounted into the DOM.');
    }
    this.table.layout();
    this.updateSelectedRowsIds();
    this.table.listen('MDCDataTable:selectedAll', () => {
      this.handleChangeSelection();
    });
    this.table.listen('MDCDataTable:unselectedAll', () => {
      this.handleChangeSelection();
    });
    this.table.listen('MDCDataTable:rowSelectionChanged', () => {
      this.handleChangeSelection();
    });
  }
  render() {
    return (h(Host, null,
      h("div", { class: "mdc-data-table w-full" },
        h("div", { class: "mdc-data-table__table-container" },
          h("table", { class: "mdc-data-table__table", "aria-label": this.ariaLabel },
            h("thead", { class: "mdc-data-table__header-row" },
              h("slot", { name: "head" })),
            h("tbody", { class: "mdc-data-table__content" },
              h("slot", { name: "body" })))))));
  }
  static get is() { return "lp-table"; }
  static get properties() { return {
    "ariaLabel": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Text describing the table purpose."
      },
      "attribute": "aria-label",
      "reflect": false
    }
  }; }
  static get events() { return [{
      "method": "selectionChanged",
      "name": "selectionChanged",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "Id[]",
        "resolved": "string[]",
        "references": {
          "Id": {
            "location": "import",
            "path": "../../types/id.type"
          }
        }
      }
    }]; }
}
