import { init, loadTransferData, selectErrors, selectLoading, selectTransactionOrderList, selectTransferPayload, store, } from '@listo-paye/sdk-core';
import { Component, h, Host, Prop, State } from '@stencil/core';
import { Intent } from '../../types/intent.type';
/**
 * All-in-one component to handle Transfers.
 *
 */
export class LpTransfer {
  constructor() {
    this.isOpen = false;
    // State-computed properties.
    this.loading = [];
    this.isLoading = true;
    this.hasErrors = false;
    this.errors = [];
    this.shouldDisablePrimaryAction = true;
    // @ts-ignore
    this.orderList = [];
    this.currentStep = 0;
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = store.getState();
      this.loading = selectLoading(this.state);
      this.errors = selectErrors(this.state);
      this.isLoading = !!this.loading.length;
      this.hasErrors = !!this.errors.length;
      this.shouldDisablePrimaryAction = this.isLoading || this.hasErrors;
      this.orderList = selectTransactionOrderList(this.state);
    };
    this.loadSDK = async () => {
      try {
        await init(this.config);
        await loadTransferData({
          date: this.date,
        });
      }
      catch (error) {
        console.error(error);
      }
    };
    this.previous = () => {
      this.currentStep--;
    };
    this.next = () => {
      this.currentStep++;
    };
    this.handleOpenView = async () => {
      this.isOpen = true;
      await this.loadSDK();
    };
    this.handleCancel = () => {
      if (this.isOpen) {
        this.isOpen = false;
      }
    };
    this.handleContinue = () => {
      if (!this.shouldDisablePrimaryAction) {
        this.next();
      }
    };
    this.handlePrevious = () => {
      if (!this.shouldDisablePrimaryAction) {
        this.previous();
      }
    };
    this.handleInitiatePayement = () => {
      if (!this.shouldDisablePrimaryAction) {
        this.transferPayload = selectTransferPayload(this.state);
        // DEBUG
        console.debug('transferPayload', this.transferPayload);
        //
      }
    };
  }
  async componentWillLoad() {
    // Initial call.
    this.handleStoreChange();
    // Global state subscription.
    this.unsubscribe = store.subscribe(this.handleStoreChange);
  }
  render() {
    const isStepSelection = this.isOpen && this.currentStep === 0;
    const isStepSummary = this.isOpen && this.currentStep === 1;
    const isStepRedirect = this.isOpen && this.currentStep === 2;
    if (isStepSelection) {
      return (h(Host, null,
        h("div", { onClick: this.handleOpenView },
          h("slot", { name: "trigger-control" })),
        h("lp-dialog", { isOpen: this.isOpen, "dialog-title": "Payer les salaires", surfaceStyle: { minWidth: '800px', minHeight: '600px' } },
          h("lp-view-selection", { slot: "content" }),
          h("lp-dialog-button", { slot: "action", onClicked: this.handleCancel }, "Annuler"),
          h("lp-dialog-button", { slot: "action", disabled: this.shouldDisablePrimaryAction, intent: Intent.PRIMARY, onClicked: this.handleContinue }, this.hasErrors ? 'OK' : 'Continuer'))));
    }
    if (isStepSummary) {
      return (h(Host, null,
        h("div", { onClick: this.handleOpenView },
          h("slot", { name: "trigger-control" })),
        h("lp-dialog", { isOpen: this.isOpen, "dialog-title": "Payer les salaires", surfaceStyle: { minWidth: '800px', minHeight: '600px' } },
          h("lp-view-summary", { slot: "content" }),
          h("lp-dialog-button", { slot: "action", onClicked: this.handlePrevious }, this.hasErrors ? 'Annuler' : 'Précédent'),
          h("lp-dialog-button", { slot: "action", disabled: this.shouldDisablePrimaryAction, intent: Intent.PRIMARY, onClicked: this.handleContinue }, this.hasErrors ? 'OK' : 'Initier le paiement'))));
    }
    if (isStepRedirect) {
      return (h(Host, null,
        h("div", { onClick: this.handleOpenView },
          h("slot", { name: "trigger-control" })),
        h("lp-dialog", { isOpen: this.isOpen, "dialog-title": "Payer les salaires", surfaceStyle: { minWidth: '800px', minHeight: '600px' } },
          h("lp-view-redirection", { slot: "content" }),
          h("lp-dialog-button", { slot: "action", onClicked: this.handlePrevious }, this.hasErrors ? 'Annuler' : 'Précédent'),
          h("lp-dialog-button", { slot: "action", disabled: this.shouldDisablePrimaryAction, intent: Intent.PRIMARY, onClicked: this.handleContinue }, this.hasErrors ? 'OK' : 'Initier le paiement'))));
    }
    return (h(Host, null,
      h("div", { onClick: this.handleOpenView },
        h("slot", { name: "trigger-control" }))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
  static get is() { return "lp-transfer"; }
  static get properties() { return {
    "config": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "Config",
        "resolved": "Config",
        "references": {
          "Config": {
            "location": "import",
            "path": "@listo-paye/sdk-core"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    },
    "date": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "date",
      "reflect": false
    }
  }; }
  static get states() { return {
    "isOpen": {},
    "state": {},
    "currentStep": {}
  }; }
}
