import { html } from 'lit-html';
import readme from './readme.md';
const argTypes = {
  open: {
    type: { name: 'boolean', required: false },
    defaultValue: false,
    description: 'Whether the dialog is opened or not.',
    table: {
      type: { summary: 'boolean' },
      defaultValue: { summary: false },
    },
  },
  dialogTitle: {
    name: 'dialog-title',
    type: { name: 'string', required: true },
    defaultValue: 'Payer les salaires',
    description: 'Title of the dialog showed on the top.',
    table: {
      type: { summary: 'string' },
      defaultValue: { summary: 'Payer les salaires' },
    },
  },
  onCanceled: {
    name: 'canceled',
    type: { name: 'Event', required: true },
    description: 'Emitted event when dialog has been closed because user canceled the action.',
    table: {
      type: { summary: 'Event' },
    },
  },
  onConfirmed: {
    name: 'confirmed',
    type: { name: 'Event', required: true },
    description: 'Emitted event when dialog has been closed because user confirmed the action.',
    table: {
      type: { summary: 'Event' },
    },
  },
};
export default {
  title: 'Lp Transfer',
  parameters: {
    notes: readme,
    actions: {
      handles: ['canceled', 'confirmed'],
    },
  },
  argTypes,
};
const Template = ({ config, date }) => {
  return html ` <lp-transfer .config=${config} date=${date}>
    <lp-button slot="trigger-control">Payer les salaires...</lp-button>
  </lp-transfer>`;
};
export const Idle = Template.bind({});
Idle.args = {
  config: {
    sponsorCredentials: {
      email: 'bchoain@listo.pro',
      password: 'D],M8jy',
    },
    etablissementId: '22ab870b-2c10-4806-ae0b-8aac078e79f9',
  },
  date: '2020-07-01',
  onCanceled: () => {
    console.log('Canceled');
  },
  onConfirmed: () => {
    console.log('Confirmed');
  },
};
