import { initiateTransfer, selectErrors, selectLoading, store, } from '@listo-paye/sdk-core';
import { Component, h, Host, State } from '@stencil/core';
import { Intent } from '../../types/intent.type';
export class LpViewRedirection {
  constructor() {
    // State-computed properties.
    this.errors = [];
    this.isLoading = true;
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = store.getState();
      this.errors = selectErrors(this.state);
      const loading = selectLoading(this.state);
      this.isLoading = !!loading.length;
    };
    this.setupStore = () => {
      // Initial global State update.
      this.handleStoreChange();
      // Global state subscription.
      this.unsubscribe = store.subscribe(this.handleStoreChange);
    };
    this.handleInitiatePayement = async () => {
      this.redirectionUrl = await initiateTransfer();
    };
  }
  async componentWillLoad() {
    this.setupStore();
    await this.handleInitiatePayement();
  }
  render() {
    const hasErrors = !!this.errors.length;
    if (this.isLoading) {
      return h("p", null, "Loading...");
    }
    if (hasErrors) {
      return (h(Host, { class: "space-y-2" }, this.errors.map((error, index) => (h("lp-callout", { key: index, intent: Intent.DANGER },
        h("p", { slot: "message" }, error.message))))));
    }
    return (h(Host, { class: "flex items-center justify-center h-full" },
      h("lp-anchor-button", { href: this.redirectionUrl, 
        // target="_blank" // Open new tab or window.
        rel: "noreferrer" },
        "Se connecter \u00E0 votre banque",
        h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-3 w-3 ml-0.5 mb-px", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor", "stroke-width": "2" },
          h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", d: "M10 6H6a2 2 0 00-2 2v10a2 2 0 002 2h10a2 2 0 002-2v-4M14 4h6m0 0v6m0-6L10 14" })))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
  static get is() { return "lp-view-redirection"; }
  static get states() { return {
    "state": {},
    "redirectionUrl": {}
  }; }
}
