import { selectErrors, selectLoading, selectTransactionOrderList, setOrders, store, } from '@listo-paye/sdk-core';
import { Component, h, Host, State } from '@stencil/core';
import { Intent } from '../../types/intent.type';
/**
 * Load, display & handle user transfer order data.
 *
 */
export class LpViewSelection {
  constructor() {
    // State-computed properties.
    this.errors = [];
    this.isLoading = true;
    this.orderList = [];
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = store.getState();
      this.errors = selectErrors(this.state);
      const loading = selectLoading(this.state);
      this.isLoading = !!loading.length;
      this.orderList = selectTransactionOrderList(this.state);
    };
    this.setupStore = () => {
      // Initial global State update.
      this.handleStoreChange();
      // Global state subscription.
      this.unsubscribe = store.subscribe(this.handleStoreChange);
    };
    this.handleSelectionChanged = (event) => {
      const selection = event.detail;
      const newOrderList = this.orderList.filter((order) => selection.includes(order.iban));
      setOrders(newOrderList);
    };
  }
  componentWillLoad() {
    this.setupStore();
  }
  render() {
    const hasErrors = !!this.errors.length;
    if (this.isLoading) {
      return h("p", null, "Nous pr\u00E9parons les donn\u00E9es de virements...");
    }
    if (hasErrors) {
      return (h(Host, { class: "space-y-2" }, this.errors.map((error, index) => (h("lp-callout", { key: index, intent: Intent.DANGER },
        h("p", { slot: "message" }, error.message))))));
    }
    return (h(Host, { class: "pt-4" },
      h("p", null, "S\u00E9lectionner les salari\u00E9s auxquels vous souhaiter verser le salaire."),
      h("lp-table", { "aria-label": "Liste des sommes \u00E0 verser aux employ\u00E9s", class: "block mt-4", onSelectionChanged: this.handleSelectionChanged },
        h("lp-table-row-header", { slot: "head" },
          h("lp-table-cell-header", { "has-checkbox": "true" },
            h("lp-checkbox", { "aria-label": "S\u00E9lectionner tous les rangs" })),
          h("lp-table-cell-header", null, "Employ\u00E9"),
          h("lp-table-cell-header", { type: "numeric" }, "Total"),
          h("lp-table-cell-header", null, "IBAN"),
          h("lp-table-cell-header", null, "RIB")),
        this.orderList.map((order) => (h("lp-table-row", { key: order.iban, "data-row-id": order.iban, slot: "body", selected: order.isEnabled },
          h("lp-table-cell", null,
            h("lp-checkbox", { value: order.iban, checked: order.isEnabled, class: "mdc-data-table__row-checkbox", "aria-labelledby": order.iban })),
          h("lp-table-cell-header", { "cell-idc": order.iban, scope: "row" },
            h("lp-employee", null,
              h("span", { slot: "firstName" }, order.prenom),
              h("span", { slot: "lastName", class: "font-bold" }, order.nom))),
          h("lp-table-cell", { type: "numeric" },
            order.netAPayer,
            " \u20AC"),
          h("lp-table-cell", null,
            h("lp-iban", { iban: order.iban })),
          h("lp-table-cell", null,
            h("span", { class: "inline-block font-mono mdc-typography mdc-typography--body2" }, order.bic))))))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
  static get is() { return "lp-view-selection"; }
  static get states() { return {
    "state": {}
  }; }
}
