import { HTMLElement, createEvent, h, proxyCustomElement } from '@stencil/core/internal/client';
import { c as clsx } from './clsx.m.js';
import { V as Variant, d as defineCustomElement$1 } from './lp-button2.js';

let LpAnchorButton = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.clicked = createEvent(this, "clicked", 7);
    /**
     * Button variant.
     */
    this.variant = Variant.CONTAINED;
    /**
     * Disable button.
     */
    this.disabled = false;
    this.handleClick = (event) => {
      this.clicked.emit(event);
    };
  }
  render() {
    if (this.disabled) {
      return (h("lp-button", { disabled: true, variant: this.variant }, h("slot", null)));
    }
    return (h("a", { class: clsx('mdc-button', {
        'mdc-button--outlined': this.variant === Variant.OUTLINED,
        'mdc-button--raised': this.variant === Variant.CONTAINED,
      }), "aria-disabled": this.disabled, href: this.href, rel: this.rel, target: this.target, onClick: this.handleClick }, h("div", { class: "mdc-button__ripple" }), h("span", { class: "mdc-button__label flex items-center" }, h("slot", null))));
  }
};
LpAnchorButton = /*@__PURE__*/ proxyCustomElement(LpAnchorButton, [4, "lp-anchor-button", {
    "href": [1],
    "target": [1],
    "rel": [1],
    "variant": [1],
    "disabled": [4]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["lp-anchor-button", "lp-button"];
  components.forEach(tagName => { switch (tagName) {
    case "lp-anchor-button":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, LpAnchorButton);
      }
      break;
    case "lp-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { LpAnchorButton as L, defineCustomElement as d };
