import { HTMLElement, createEvent, h, proxyCustomElement } from '@stencil/core/internal/client';
import { c as clsx } from './clsx.m.js';

/**
 * The four basic variants.
 */
const Variant = {
  TEXT: 'text',
  OUTLINED: 'outlined',
  CONTAINED: 'contained',
  FILLED: 'filled',
};

let LpButton = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.clicked = createEvent(this, "clicked", 7);
    /**
     * Button variant.
     */
    this.variant = Variant.CONTAINED;
    /**
     * Disable button.
     */
    this.disabled = false;
    this.handleClick = (event) => {
      this.clicked.emit(event);
    };
  }
  render() {
    return (h("button", { class: clsx('mdc-button', {
        'mdc-button--outlined': this.variant === Variant.OUTLINED,
        'mdc-button--raised': this.variant === Variant.CONTAINED,
      }), disabled: this.disabled, onClick: this.handleClick }, h("div", { class: "mdc-button__ripple" }), h("span", { class: "mdc-button__label flex items-center" }, h("slot", null))));
  }
};
LpButton = /*@__PURE__*/ proxyCustomElement(LpButton, [4, "lp-button", {
    "variant": [1],
    "disabled": [4]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["lp-button"];
  components.forEach(tagName => { switch (tagName) {
    case "lp-button":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, LpButton);
      }
      break;
  } });
}

export { LpButton as L, Variant as V, defineCustomElement as d };
