import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
import { c as clsx } from './clsx.m.js';
import { I as Intent } from './intent.type.js';

let LpCallout = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /**
     * Visual intent color to apply to background, title, and icon.
     */
    this.intent = Intent.NONE;
  }
  componentWillLoad() {
    this.hasTitleSlot = !!this.hostElement.querySelector('[slot="title"]');
    this.hasMessageSlot = !!this.hostElement.querySelector('[slot="message"]');
  }
  render() {
    let icon, color;
    switch (this.intent) {
      case 'primary':
        icon = (h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-5 w-5", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor", "stroke-width": 2 }, h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", d: "M13 16h-1v-4h-1m1-4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" })));
        color = 'text-primary before:bg-primary before:opacity-5';
        break;
      case 'success':
        icon = (h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-5 w-5", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor", "stroke-width": 2 }, h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", d: "M9 12l2 2 4-4M7.835 4.697a3.42 3.42 0 001.946-.806 3.42 3.42 0 014.438 0 3.42 3.42 0 001.946.806 3.42 3.42 0 013.138 3.138 3.42 3.42 0 00.806 1.946 3.42 3.42 0 010 4.438 3.42 3.42 0 00-.806 1.946 3.42 3.42 0 01-3.138 3.138 3.42 3.42 0 00-1.946.806 3.42 3.42 0 01-4.438 0 3.42 3.42 0 00-1.946-.806 3.42 3.42 0 01-3.138-3.138 3.42 3.42 0 00-.806-1.946 3.42 3.42 0 010-4.438 3.42 3.42 0 00.806-1.946 3.42 3.42 0 013.138-3.138z" })));
        color = 'text-primary before:bg-primary before:opacity-5';
        break;
      case 'danger':
        icon = (h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-5 w-5", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor", "stroke-width": "2" }, h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", d: "M12 8v4m0 4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" })));
        color = 'text-error before:bg-error before:opacity-5';
        break;
      default:
        icon = (h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-5 w-5", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor", "stroke-width": 2 }, h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", d: "M13 16h-1v-4h-1m1-4h.01M21 12a9 9 0 11-18 0 9 9 0 0118 0z" })));
        color = 'before:bg-on-surface before:opacity-5';
    }
    return (h(Host, { class: clsx('grid grid-cols-[auto_1fr] gap-x-1 gap-y-0.5 items-center p-3', 'before:rounded-large relative before:absolute before:inset-0', color) }, h("div", { class: "justify-center" }, icon), this.hasTitleSlot && (h("h2", { class: "col-start-2 mdc-typography mdc-typography--subtitle1" }, h("slot", { name: "title" }))), this.hasMessageSlot && (h("p", { class: "col-start-2 mdc-typography mdc-typography--body2" }, h("slot", { name: "message" })))));
  }
  get hostElement() { return this; }
};
LpCallout = /*@__PURE__*/ proxyCustomElement(LpCallout, [4, "lp-callout", {
    "intent": [1]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["lp-callout"];
  components.forEach(tagName => { switch (tagName) {
    case "lp-callout":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, LpCallout);
      }
      break;
  } });
}

export { LpCallout as L, defineCustomElement as d };
