import { HTMLElement, h, proxyCustomElement } from '@stencil/core/internal/client';
import { M as MDCCheckbox } from './component.js';

/**
 * @license
 * Copyright 2016 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

/**
 * @license
 * Copyright 2019 Google Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

let LpCheckbox = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /**
     * Whether checkbox is indeterminate or not.
     */
    this.indeterminate = false;
    /**
     * Whether checkbox is checked or not.
     */
    this.checked = false;
    /**
     * Whether checkbox is disabled or not.
     */
    this.disabled = false;
    this.syncInternalCheckboxState = () => {
      this.checkbox.value = this.value;
      this.checkbox.indeterminate = this.indeterminate;
      this.checkbox.checked = this.checked;
      this.checkbox.disabled = this.disabled;
    };
    this.initiateCheckbox = () => {
      this.checkbox = new MDCCheckbox(this.hostElement.querySelector('.mdc-checkbox'));
      if (!this.checkbox) {
        throw new Error('Unable to initiate MDCCheckbox component. Be sure it is mounted into the DOM.');
      }
      this.syncInternalCheckboxState();
    };
  }
  componentDidLoad() {
    this.initiateCheckbox();
  }
  componentWillUpdate() {
    this.syncInternalCheckboxState();
  }
  render() {
    return (h("div", { class: "mdc-checkbox" }, h("input", { type: "checkbox", id: this.inputId, class: "mdc-checkbox__native-control", "aria-label": this.ariaLabel }), h("div", { class: "mdc-checkbox__background" }, h("svg", { class: "mdc-checkbox__checkmark", viewBox: "0 0 24 24" }, h("path", { class: "mdc-checkbox__checkmark-path", fill: "none", d: "M1.73,12.91 8.1,19.28 22.79,4.59" })), h("div", { class: "mdc-checkbox__mixedmark" })), h("div", { class: "mdc-checkbox__ripple" })));
  }
  get hostElement() { return this; }
};
LpCheckbox = /*@__PURE__*/ proxyCustomElement(LpCheckbox, [0, "lp-checkbox", {
    "inputId": [1, "input-id"],
    "ariaLabel": [1, "aria-label"],
    "ariaLabelledby": [1, "aria-labelledby"],
    "value": [1],
    "indeterminate": [4],
    "checked": [4],
    "disabled": [4]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["lp-checkbox"];
  components.forEach(tagName => { switch (tagName) {
    case "lp-checkbox":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, LpCheckbox);
      }
      break;
  } });
}

export { LpCheckbox as L, defineCustomElement as d };
