import { HTMLElement, createEvent, h, proxyCustomElement } from '@stencil/core/internal/client';
import { I as Intent } from './intent.type.js';
import { V as Variant, d as defineCustomElement$1 } from './lp-button2.js';

let LpDialogButton = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.clicked = createEvent(this, "clicked", 7);
    this.intent = Intent.NONE;
    this.disabled = false;
  }
  handleClick(event) {
    event.stopPropagation();
    if (!this.disabled) {
      this.clicked.emit(event);
    }
  }
  render() {
    const variant = this.intent === Intent.PRIMARY ? Variant.CONTAINED : Variant.TEXT;
    const action = this.intent === Intent.PRIMARY ? 'primary' : 'secondary';
    return (h("lp-button", { class: "mdc-dialog__button", variant: variant, disabled: this.disabled, "data-mdc-dialog-action": action, "data-mdc-dialog-button-default": this.default }, h("slot", null)));
  }
};
LpDialogButton = /*@__PURE__*/ proxyCustomElement(LpDialogButton, [4, "lp-dialog-button", {
    "intent": [1],
    "default": [4],
    "disabled": [4]
  }, [[2, "click", "handleClick"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["lp-dialog-button", "lp-button"];
  components.forEach(tagName => { switch (tagName) {
    case "lp-dialog-button":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, LpDialogButton);
      }
      break;
    case "lp-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { LpDialogButton as L, defineCustomElement as d };
