import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
import { c as clsx } from './clsx.m.js';

let LpTableCellHeader = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /**
     * Set the scope of the header cell.
     * I.e. whether the header cell is used within a row or a column (by default).
     */
    this.scope = 'col';
    /**
     * The type of the content.
     * Numeric content will be justified on the right.
     */
    this.type = 'text';
    /**
     * Whether the cell contains a checkbox for row selection or not.
     */
    this.hasCheckbox = false;
  }
  componentDidRender() {
    if (this.hasCheckbox) {
      const checkbox = document.querySelector('.mdc-checkbox');
      if (checkbox) {
        checkbox.classList.add('mdc-data-table__header-row-checkbox');
      }
    }
  }
  render() {
    return (h(Host, { class: "contents" }, h("th", { class: clsx('h-12 align-middle', // Patch styles due to `Host` element breaking inherited rules.
      {
        'mdc-data-table__cell': this.scope === 'row',
        'mdc-data-table__header-cell': this.scope === 'col',
        'mdc-data-table__header-cell--numeric': this.type === 'numeric',
        'mdc-data-table__header-cell--checkbox': this.hasCheckbox,
        'pl-3': this.hasCheckbox, // Fix left padding which is not correctly applied.
      }), role: this.scope === 'col' ? 'columnheader' : undefined, id: this.scope === 'row' ? this.cellId : undefined, scope: this.scope }, h("slot", null))));
  }
};
LpTableCellHeader = /*@__PURE__*/ proxyCustomElement(LpTableCellHeader, [4, "lp-table-cell-header", {
    "scope": [1],
    "cellId": [1, "cell-id"],
    "type": [1],
    "hasCheckbox": [4, "has-checkbox"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["lp-table-cell-header"];
  components.forEach(tagName => { switch (tagName) {
    case "lp-table-cell-header":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, LpTableCellHeader);
      }
      break;
  } });
}

export { LpTableCellHeader as L, defineCustomElement as d };
