import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
import { c as clsx } from './clsx.m.js';

let LpTableCell = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    /**
     * The type of the content.
     * Numeric content will be justified on the right.
     */
    this.type = 'text';
    /**
     * Whether the cell contains a checkbox for row selection or not.
     */
    this.hasCheckbox = false;
  }
  componentDidRender() {
    // Add an extra specific CSS class to the inner checkbox if it exists.
    if (this.hasCheckbox) {
      const checkbox = document.querySelector('.mdc-checkbox');
      if (checkbox) {
        checkbox.classList.add('mdc-data-table__row-checkbox');
      }
    }
  }
  render() {
    return (h(Host, { class: "contents" }, h("td", { class: clsx('h-12 align-middle', // Patch styles due to `Host` element breaking inherited rules.
      'mdc-data-table__cell', {
        'mdc-data-table__cell--numeric': this.type === 'numeric',
        'mdc-data-table__cell--checkbox': this.hasCheckbox,
      }) }, h("slot", null))));
  }
};
LpTableCell = /*@__PURE__*/ proxyCustomElement(LpTableCell, [4, "lp-table-cell", {
    "type": [1],
    "hasCheckbox": [4, "has-checkbox"]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["lp-table-cell"];
  components.forEach(tagName => { switch (tagName) {
    case "lp-table-cell":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, LpTableCell);
      }
      break;
  } });
}

export { LpTableCell as L, defineCustomElement as d };
