import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
import { store, selectLoading, selectErrors, selectTransactionOrderList, init, loadTransferData, selectTransferPayload } from '@listo-paye/sdk-core';
import { I as Intent } from './intent.type.js';
import { d as defineCustomElement$j } from './lp-accordion2.js';
import { d as defineCustomElement$i } from './lp-anchor-button2.js';
import { d as defineCustomElement$h } from './lp-button2.js';
import { d as defineCustomElement$g } from './lp-callout2.js';
import { d as defineCustomElement$f } from './lp-checkbox2.js';
import { d as defineCustomElement$e } from './lp-dialog2.js';
import { d as defineCustomElement$d } from './lp-dialog-actions2.js';
import { d as defineCustomElement$c } from './lp-dialog-button2.js';
import { d as defineCustomElement$b } from './lp-employee2.js';
import { d as defineCustomElement$a } from './lp-iban2.js';
import { d as defineCustomElement$9 } from './lp-table2.js';
import { d as defineCustomElement$8 } from './lp-table-cell2.js';
import { d as defineCustomElement$7 } from './lp-table-cell-header2.js';
import { d as defineCustomElement$6 } from './lp-table-row2.js';
import { d as defineCustomElement$5 } from './lp-table-row-header2.js';
import { d as defineCustomElement$4 } from './lp-view-redirection2.js';
import { d as defineCustomElement$3 } from './lp-view-selection2.js';
import { d as defineCustomElement$2 } from './lp-view-summary2.js';

let LpTransfer$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.isOpen = false;
    // State-computed properties.
    this.loading = [];
    this.isLoading = true;
    this.hasErrors = false;
    this.errors = [];
    this.shouldDisablePrimaryAction = true;
    // @ts-ignore
    this.orderList = [];
    this.currentStep = 0;
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = store.getState();
      this.loading = selectLoading(this.state);
      this.errors = selectErrors(this.state);
      this.isLoading = !!this.loading.length;
      this.hasErrors = !!this.errors.length;
      this.shouldDisablePrimaryAction = this.isLoading || this.hasErrors;
      this.orderList = selectTransactionOrderList(this.state);
    };
    this.loadSDK = async () => {
      try {
        await init(this.config);
        await loadTransferData({
          date: this.date,
        });
      }
      catch (error) {
        console.error(error);
      }
    };
    this.previous = () => {
      this.currentStep--;
    };
    this.next = () => {
      this.currentStep++;
    };
    this.handleOpenView = async () => {
      this.isOpen = true;
      await this.loadSDK();
    };
    this.handleCancel = () => {
      if (this.isOpen) {
        this.isOpen = false;
      }
    };
    this.handleContinue = () => {
      if (!this.shouldDisablePrimaryAction) {
        this.next();
      }
    };
    this.handlePrevious = () => {
      if (!this.shouldDisablePrimaryAction) {
        this.previous();
      }
    };
    this.handleInitiatePayement = () => {
      if (!this.shouldDisablePrimaryAction) {
        this.transferPayload = selectTransferPayload(this.state);
        // DEBUG
        console.debug('transferPayload', this.transferPayload);
        //
      }
    };
  }
  async componentWillLoad() {
    // Initial call.
    this.handleStoreChange();
    // Global state subscription.
    this.unsubscribe = store.subscribe(this.handleStoreChange);
  }
  render() {
    const isStepSelection = this.isOpen && this.currentStep === 0;
    const isStepSummary = this.isOpen && this.currentStep === 1;
    const isStepRedirect = this.isOpen && this.currentStep === 2;
    if (isStepSelection) {
      return (h(Host, null, h("div", { onClick: this.handleOpenView }, h("slot", { name: "trigger-control" })), h("lp-dialog", { isOpen: this.isOpen, "dialog-title": "Payer les salaires", surfaceStyle: { minWidth: '800px', minHeight: '600px' } }, h("lp-view-selection", { slot: "content" }), h("lp-dialog-button", { slot: "action", onClicked: this.handleCancel }, "Annuler"), h("lp-dialog-button", { slot: "action", disabled: this.shouldDisablePrimaryAction, intent: Intent.PRIMARY, onClicked: this.handleContinue }, this.hasErrors ? 'OK' : 'Continuer'))));
    }
    if (isStepSummary) {
      return (h(Host, null, h("div", { onClick: this.handleOpenView }, h("slot", { name: "trigger-control" })), h("lp-dialog", { isOpen: this.isOpen, "dialog-title": "Payer les salaires", surfaceStyle: { minWidth: '800px', minHeight: '600px' } }, h("lp-view-summary", { slot: "content" }), h("lp-dialog-button", { slot: "action", onClicked: this.handlePrevious }, this.hasErrors ? 'Annuler' : 'Précédent'), h("lp-dialog-button", { slot: "action", disabled: this.shouldDisablePrimaryAction, intent: Intent.PRIMARY, onClicked: this.handleContinue }, this.hasErrors ? 'OK' : 'Initier le paiement'))));
    }
    if (isStepRedirect) {
      return (h(Host, null, h("div", { onClick: this.handleOpenView }, h("slot", { name: "trigger-control" })), h("lp-dialog", { isOpen: this.isOpen, "dialog-title": "Payer les salaires", surfaceStyle: { minWidth: '800px', minHeight: '600px' } }, h("lp-view-redirection", { slot: "content" }), h("lp-dialog-button", { slot: "action", onClicked: this.handlePrevious }, this.hasErrors ? 'Annuler' : 'Précédent'), h("lp-dialog-button", { slot: "action", disabled: this.shouldDisablePrimaryAction, intent: Intent.PRIMARY, onClicked: this.handleContinue }, this.hasErrors ? 'OK' : 'Initier le paiement'))));
    }
    return (h(Host, null, h("div", { onClick: this.handleOpenView }, h("slot", { name: "trigger-control" }))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
};
LpTransfer$1 = /*@__PURE__*/ proxyCustomElement(LpTransfer$1, [4, "lp-transfer", {
    "config": [16],
    "date": [1],
    "isOpen": [32],
    "state": [32],
    "currentStep": [32]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["lp-transfer", "lp-accordion", "lp-anchor-button", "lp-button", "lp-callout", "lp-checkbox", "lp-dialog", "lp-dialog-actions", "lp-dialog-button", "lp-employee", "lp-iban", "lp-table", "lp-table-cell", "lp-table-cell-header", "lp-table-row", "lp-table-row-header", "lp-view-redirection", "lp-view-selection", "lp-view-summary"];
  components.forEach(tagName => { switch (tagName) {
    case "lp-transfer":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, LpTransfer$1);
      }
      break;
    case "lp-accordion":
      if (!customElements.get(tagName)) {
        defineCustomElement$j();
      }
      break;
    case "lp-anchor-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$i();
      }
      break;
    case "lp-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$h();
      }
      break;
    case "lp-callout":
      if (!customElements.get(tagName)) {
        defineCustomElement$g();
      }
      break;
    case "lp-checkbox":
      if (!customElements.get(tagName)) {
        defineCustomElement$f();
      }
      break;
    case "lp-dialog":
      if (!customElements.get(tagName)) {
        defineCustomElement$e();
      }
      break;
    case "lp-dialog-actions":
      if (!customElements.get(tagName)) {
        defineCustomElement$d();
      }
      break;
    case "lp-dialog-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$c();
      }
      break;
    case "lp-employee":
      if (!customElements.get(tagName)) {
        defineCustomElement$b();
      }
      break;
    case "lp-iban":
      if (!customElements.get(tagName)) {
        defineCustomElement$a();
      }
      break;
    case "lp-table":
      if (!customElements.get(tagName)) {
        defineCustomElement$9();
      }
      break;
    case "lp-table-cell":
      if (!customElements.get(tagName)) {
        defineCustomElement$8();
      }
      break;
    case "lp-table-cell-header":
      if (!customElements.get(tagName)) {
        defineCustomElement$7();
      }
      break;
    case "lp-table-row":
      if (!customElements.get(tagName)) {
        defineCustomElement$6();
      }
      break;
    case "lp-table-row-header":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "lp-view-redirection":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "lp-view-selection":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "lp-view-summary":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}

const LpTransfer = LpTransfer$1;
const defineCustomElement = defineCustomElement$1;

export { LpTransfer, defineCustomElement };
