import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
import { store, selectErrors, selectLoading, initiateTransfer } from '@listo-paye/sdk-core';
import { I as Intent } from './intent.type.js';
import { d as defineCustomElement$3 } from './lp-anchor-button2.js';
import { d as defineCustomElement$2 } from './lp-button2.js';
import { d as defineCustomElement$1 } from './lp-callout2.js';

let LpViewRedirection = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    // State-computed properties.
    this.errors = [];
    this.isLoading = true;
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = store.getState();
      this.errors = selectErrors(this.state);
      const loading = selectLoading(this.state);
      this.isLoading = !!loading.length;
    };
    this.setupStore = () => {
      // Initial global State update.
      this.handleStoreChange();
      // Global state subscription.
      this.unsubscribe = store.subscribe(this.handleStoreChange);
    };
    this.handleInitiatePayement = async () => {
      this.redirectionUrl = await initiateTransfer();
    };
  }
  async componentWillLoad() {
    this.setupStore();
    await this.handleInitiatePayement();
  }
  render() {
    const hasErrors = !!this.errors.length;
    if (this.isLoading) {
      return h("p", null, "Loading...");
    }
    if (hasErrors) {
      return (h(Host, { class: "space-y-2" }, this.errors.map((error, index) => (h("lp-callout", { key: index, intent: Intent.DANGER }, h("p", { slot: "message" }, error.message))))));
    }
    return (h(Host, { class: "flex items-center justify-center h-full" }, h("lp-anchor-button", { href: this.redirectionUrl,
      // target="_blank" // Open new tab or window.
      rel: "noreferrer" }, "Se connecter \u00E0 votre banque", h("svg", { xmlns: "http://www.w3.org/2000/svg", class: "h-3 w-3 ml-0.5 mb-px", fill: "none", viewBox: "0 0 24 24", stroke: "currentColor", "stroke-width": "2" }, h("path", { "stroke-linecap": "round", "stroke-linejoin": "round", d: "M10 6H6a2 2 0 00-2 2v10a2 2 0 002 2h10a2 2 0 002-2v-4M14 4h6m0 0v6m0-6L10 14" })))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
};
LpViewRedirection = /*@__PURE__*/ proxyCustomElement(LpViewRedirection, [0, "lp-view-redirection", {
    "state": [32],
    "redirectionUrl": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["lp-view-redirection", "lp-anchor-button", "lp-button", "lp-callout"];
  components.forEach(tagName => { switch (tagName) {
    case "lp-view-redirection":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, LpViewRedirection);
      }
      break;
    case "lp-anchor-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "lp-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "lp-callout":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}

export { LpViewRedirection as L, defineCustomElement as d };
