import { r as registerInstance, h, e as Host } from './index-5aee6d0f.js';
import { store, selectErrors, selectLoading, selectTransactionOrderList } from '@listo-paye/sdk-core';
import { I as Intent } from './intent.type-470c4219.js';

const sumOrderAmount = (total, amount) => total + amount;
let LpViewSummary = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    // State-computed properties.
    this.errors = [];
    this.isLoading = true;
    this.orderList = [];
    this.unsubscribe = () => { };
    this.handleStoreChange = () => {
      this.state = store.getState();
      this.errors = selectErrors(this.state);
      const loading = selectLoading(this.state);
      this.isLoading = !!loading.length;
      this.orderList = selectTransactionOrderList(this.state);
    };
    this.setupStore = () => {
      // Initial global State update.
      this.handleStoreChange();
      // Global state subscription.
      this.unsubscribe = store.subscribe(this.handleStoreChange);
    };
  }
  componentWillLoad() {
    this.setupStore();
  }
  render() {
    const hasErrors = !!this.errors.length;
    if (this.isLoading) {
      return h("p", null, "Loading...");
    }
    if (hasErrors) {
      return (h(Host, { class: "space-y-2" }, this.errors.map((error, index) => (h("lp-callout", { key: index, intent: Intent.DANGER }, h("p", { slot: "message" }, error.message))))));
    }
    const currentDate = new Date();
    const formattedCurrentDate = new Intl.DateTimeFormat('fr-FR').format(currentDate);
    const totalAmount = this.orderList
      .map((order) => order.netAPayer)
      .reduce(sumOrderAmount, 0);
    return (h(Host, { class: "flex flex-col space-y-4 pt-4" }, h("lp-callout", { intent: Intent.PRIMARY }, h("span", { slot: "title" }, "Confirmer la demande de virement ?"), h("div", { slot: "message", class: "text-on-secondary/100" }, h("p", null, "Confirmez-vous la demande de virement dun total de", h("strong", { class: "ml-1 text-primary" }, totalAmount, " \u20AC"), " ?"), h("p", null, "Vous serez ensuite redirig\u00E9 vers le site de votre banque."))), h("lp-accordion", { label: "D\u00E9tails" }, h("p", null, h("ul", { class: "flex space-x-4" }, h("li", { class: "flex items-center space-x-2" }, h("span", { class: "mt-[2px] mdc-typography mdc-typography--overline leading-none" }, "P\u00E9riode de paiement"), h("span", { class: "mdc-typography mdc-typography--body2 text-primary" }, "2020-07-01")), h("li", { class: "flex items-center space-x-2" }, h("span", { class: "mt-[2px] mdc-typography mdc-typography--overline leading-none" }, "Date execution"), h("span", { class: "mdc-typography mdc-typography--body2 text-primary" }, formattedCurrentDate)))), h("lp-table", { "aria-label": "Liste des sommes \u00E0 verser aux employ\u00E9s", class: "block mt-4" }, h("lp-table-row-header", { slot: "head" }, h("lp-table-cell-header", null, "Employ\u00E9"), h("lp-table-cell-header", { type: "numeric" }, "Total"), h("lp-table-cell-header", null, "IBAN"), h("lp-table-cell-header", null, "RIB")), this.orderList.map((order) => (h("lp-table-row", { key: order.iban, "data-row-id": order.iban, slot: "body" }, h("lp-table-cell-header", { "cell-idc": order.iban, scope: "row" }, h("lp-employee", null, h("span", { slot: "firstName" }, order.prenom), h("span", { slot: "lastName", class: "font-bold" }, order.nom))), h("lp-table-cell", { type: "numeric" }, order.netAPayer, " \u20AC"), h("lp-table-cell", null, h("lp-iban", { iban: order.iban })), h("lp-table-cell", null, h("span", { class: "inline-block font-mono mdc-typography mdc-typography--body2" }, order.bic)))))))));
  }
  disconnectedCallback() {
    this.unsubscribe();
  }
};

export { LpViewSummary as lp_view_summary };
