import { B as BUILD, c as consoleDevInfo, p as plt, w as win, H, d as doc, N as NAMESPACE, a as promiseResolve, b as bootstrapLazy } from './index-5aee6d0f.js';
import { g as globalScripts } from './app-globals-0f993ce5.js';

/*
 Stencil Client Patch Browser v2.12.1 | MIT Licensed | https://stenciljs.com
 */
const getDynamicImportFunction = (namespace) => `__sc_import_${namespace.replace(/\s|-/g, '_')}`;
const patchBrowser = () => {
    // NOTE!! This fn cannot use async/await!
    if (BUILD.isDev && !BUILD.isTesting) {
        consoleDevInfo('Running in development mode.');
    }
    if (BUILD.cssVarShim) {
        // shim css vars
        plt.$cssShim$ = win.__cssshim;
    }
    if (BUILD.cloneNodeFix) {
        // opted-in to polyfill cloneNode() for slot polyfilled components
        patchCloneNodeFix(H.prototype);
    }
    if (BUILD.profile && !performance.mark) {
        // not all browsers support performance.mark/measure (Safari 10)
        performance.mark = performance.measure = () => {
            /*noop*/
        };
        performance.getEntriesByName = () => [];
    }
    // @ts-ignore
    const scriptElm = BUILD.scriptDataOpts || BUILD.safari10 || BUILD.dynamicImportShim
        ? Array.from(doc.querySelectorAll('script')).find((s) => new RegExp(`\/${NAMESPACE}(\\.esm)?\\.js($|\\?|#)`).test(s.src) ||
            s.getAttribute('data-stencil-namespace') === NAMESPACE)
        : null;
    const importMeta = import.meta.url;
    const opts = BUILD.scriptDataOpts ? scriptElm['data-opts'] || {} : {};
    if (BUILD.safari10 && 'onbeforeload' in scriptElm && !history.scrollRestoration /* IS_ESM_BUILD */) {
        // Safari < v11 support: This IF is true if it's Safari below v11.
        // This fn cannot use async/await since Safari didn't support it until v11,
        // however, Safari 10 did support modules. Safari 10 also didn't support "nomodule",
        // so both the ESM file and nomodule file would get downloaded. Only Safari
        // has 'onbeforeload' in the script, and "history.scrollRestoration" was added
        // to Safari in v11. Return a noop then() so the async/await ESM code doesn't continue.
        // IS_ESM_BUILD is replaced at build time so this check doesn't happen in systemjs builds.
        return {
            then() {
                /* promise noop */
            },
        };
    }
    if (!BUILD.safari10 && importMeta !== '') {
        opts.resourcesUrl = new URL('.', importMeta).href;
    }
    else if (BUILD.dynamicImportShim || BUILD.safari10) {
        opts.resourcesUrl = new URL('.', new URL(scriptElm.getAttribute('data-resources-url') || scriptElm.src, win.location.href)).href;
        if (BUILD.dynamicImportShim) {
            patchDynamicImport(opts.resourcesUrl, scriptElm);
        }
        if (BUILD.dynamicImportShim && !win.customElements) {
            // module support, but no custom elements support (Old Edge)
            // @ts-ignore
            return import(/* webpackChunkName: "polyfills-dom" */ './dom-ba83fb9d.js').then(() => opts);
        }
    }
    return promiseResolve(opts);
};
const patchDynamicImport = (base, orgScriptElm) => {
    const importFunctionName = getDynamicImportFunction(NAMESPACE);
    try {
        // test if this browser supports dynamic imports
        // There is a caching issue in V8, that breaks using import() in Function
        // By generating a random string, we can workaround it
        // Check https://bugs.chromium.org/p/chromium/issues/detail?id=990810 for more info
        win[importFunctionName] = new Function('w', `return import(w);//${Math.random()}`);
    }
    catch (e) {
        // this shim is specifically for browsers that do support "esm" imports
        // however, they do NOT support "dynamic" imports
        // basically this code is for old Edge, v18 and below
        const moduleMap = new Map();
        win[importFunctionName] = (src) => {
            const url = new URL(src, base).href;
            let mod = moduleMap.get(url);
            if (!mod) {
                const script = doc.createElement('script');
                script.type = 'module';
                script.crossOrigin = orgScriptElm.crossOrigin;
                script.src = URL.createObjectURL(new Blob([`import * as m from '${url}'; window.${importFunctionName}.m = m;`], {
                    type: 'application/javascript',
                }));
                mod = new Promise((resolve) => {
                    script.onload = () => {
                        resolve(win[importFunctionName].m);
                        script.remove();
                    };
                });
                moduleMap.set(url, mod);
                doc.head.appendChild(script);
            }
            return mod;
        };
    }
};
const patchCloneNodeFix = (HTMLElementPrototype) => {
    const nativeCloneNodeFn = HTMLElementPrototype.cloneNode;
    HTMLElementPrototype.cloneNode = function (deep) {
        if (this.nodeName === 'TEMPLATE') {
            return nativeCloneNodeFn.call(this, deep);
        }
        const clonedNode = nativeCloneNodeFn.call(this, false);
        const srcChildNodes = this.childNodes;
        if (deep) {
            for (let i = 0; i < srcChildNodes.length; i++) {
                // Node.ATTRIBUTE_NODE === 2, and checking because IE11
                if (srcChildNodes[i].nodeType !== 2) {
                    clonedNode.appendChild(srcChildNodes[i].cloneNode(true));
                }
            }
        }
        return clonedNode;
    };
};

patchBrowser().then(options => {
  globalScripts();
  return bootstrapLazy([["lp-transfer",[[4,"lp-transfer",{"config":[16],"date":[1],"isOpen":[32],"state":[32],"currentStep":[32]}]]],["lp-frame",[[0,"lp-frame",{"src":[1]}]]],["lp-select",[[4,"lp-select",{"label":[1],"labelledby":[1],"width":[1],"disabled":[4],"required":[4],"value":[1],"selectedIndex":[2,"selected-index"],"helperText":[1,"helper-text"],"valid":[4]}]]],["lp-select-option",[[4,"lp-select-option",{"value":[1],"selected":[4],"disabled":[4]}]]],["lp-view-selection",[[0,"lp-view-selection",{"state":[32]}]]],["lp-view-summary",[[0,"lp-view-summary",{"state":[32]}]]],["lp-view-redirection",[[0,"lp-view-redirection",{"state":[32],"redirectionUrl":[32]}]]],["lp-dialog",[[4,"lp-dialog",{"isOpen":[4,"open"],"dialogTitle":[1,"dialog-title"],"surfaceStyle":[16]}]]],["lp-dialog-button",[[4,"lp-dialog-button",{"intent":[1],"default":[4],"disabled":[4]},[[2,"click","handleClick"]]]]],["lp-anchor-button",[[4,"lp-anchor-button",{"href":[1],"target":[1],"rel":[1],"variant":[1],"disabled":[4]}]]],["lp-accordion",[[4,"lp-accordion",{"label":[1],"isOpen":[32]}]]],["lp-checkbox",[[0,"lp-checkbox",{"inputId":[1,"input-id"],"ariaLabel":[1,"aria-label"],"ariaLabelledby":[1,"aria-labelledby"],"value":[1],"indeterminate":[4],"checked":[4],"disabled":[4]}]]],["lp-dialog-actions",[[4,"lp-dialog-actions"]]],["lp-employee",[[4,"lp-employee"]]],["lp-iban",[[0,"lp-iban",{"iban":[1]}]]],["lp-table",[[4,"lp-table",{"ariaLabel":[1,"aria-label"]}]]],["lp-table-cell",[[4,"lp-table-cell",{"type":[1],"hasCheckbox":[4,"has-checkbox"]}]]],["lp-table-cell-header",[[4,"lp-table-cell-header",{"scope":[1],"cellId":[1,"cell-id"],"type":[1],"hasCheckbox":[4,"has-checkbox"]}]]],["lp-table-row",[[4,"lp-table-row",{"dataRowId":[1,"data-row-id"],"selected":[4]}]]],["lp-table-row-header",[[4,"lp-table-row-header"]]],["lp-button",[[4,"lp-button",{"variant":[1],"disabled":[4]}]]],["lp-callout",[[4,"lp-callout",{"intent":[1]}]]]], options);
});
